@@ -1,4 +1,5 @@
 import json
+import typing
 from unittest import mock
 import uuid
 
@@ -155,3 +156,44 @@ def test_keyboard_interupts_surface(loads: mock.MagicMock):
 
     with pytest.raises(KeyboardInterrupt):
         checker('some-value')
+
+
+JSON_CHECKERS = [
+    (_checkeromatic.JsonStringChecker, json.dumps({'f': float('NaN')})),
+    (_checkeromatic.JsonObjectStringChecker, json.dumps({'f': float('NaN')})),
+    (_checkeromatic.JsonArrayStringChecker, json.dumps([float('NaN')])),
+]
+
+
+@pytest.mark.parametrize('checker_cls,value', JSON_CHECKERS)
+def test_json_checker_doesnt_tolerate_nan(
+        checker_cls: typing.Callable,
+        value: str,
+):
+    """Should fail to validate json with Nans."""
+    value = json.dumps({'foo': float('NaN')})
+    checker = checker_cls()
+
+    passes = checker(value)
+
+    assert not passes
+
+
+def test_max_length_checker_happy_path():
+    """Should be able to validate a string within the max length."""
+    value = 'short'
+    checker = _checkeromatic.MaxLengthChecker(limit=10)
+
+    passes = checker(value)
+
+    assert passes
+
+
+def test_max_length_checker_sad_path():
+    """Should be able to reject a string outside the max length."""
+    value = 'very-very-very-very-long'
+    checker = _checkeromatic.MaxLengthChecker(limit=10)
+
+    passes = checker(value)
+
+    assert not passes
